
/*
Code for Microchip C18 compiler
Tiny library for Hitachi HD44780 (or every other lcd controller like it)
Set R/W to ground (this library is for build in characters only)
Mind to define LAT register and not PORT resister for RS and E
Four wires are connected from DB4-DB7 respectively from PORTX0 to PORTX3
*/

//set here the ports that goes to the lcd module
#define RS LATBbits.LATB0
#define EN LATBbits.LATB1
#define DATA PORTD
//set the direction register
#define DIRRS TRISBbits.TRISB0
#define DIREN TRISBbits.TRISB1
#define DIRDATA TRISD

//MHz of the oscillator clock
#define OSC_FREQ 8

/*It's really important specify the delay periods depending on the module
Some lcd are faster than others and the speed it's specified in the datasheet
I suggest to try with some big values at the begining.You can reduce them until the module works*/
#define DELAY_DATA 1 //period of characters register switch (RA=1)
#define DELAY_CMD 1 //period of commands register switch (RA=0)
#define DELAY_INIT 50 //period to wait before the module is available after power on or reset
#define DELAY_STROBE_CYCLES 3 //period of strobe of 4bit mode

//////////////////////////////////////////////////////////

//some costant for commands
#define FIRSTLINE 0x80
#define NEXT_LINE 0xC0
#define CLEAR_SCREEN 0x01
#define MOVE_LEFT 0x10
#define MOVE_RIGHT 0x14
#define VISIBLE_UNDERLINE 0x0E
#define VISIBLE_BLINKING 0x0F
#define INVISIBLE 0x0C
#define MODE 0x28
#define START 0x03
//there are many more commands that you can find online

void delay_cycles(int n);
void strobe(void);
void send(unsigned char c);
void data(unsigned char c);
void cmd(unsigned char c);
void clear(void);
void init_lcd(void);
void print_lcd(unsigned char *str);
void delay_ms(int n);
